@@ -1,10 +1,11 @@
 """
-
+:copyright: Copyright 2013 by Luc Saffre.
+:license: BSD, see LICENSE for more details.
 """
 
 import os
 
-from djangosite import Site
+from djangosite import Site, DJANGO_DEFAULT_LANGUAGE, assert_django_code
 #~ from north.babel import BabelSiteMixin
 #~ from north.babel import Site
 
@@ -62,7 +63,6 @@ LanguageInfo = collections.namedtuple('LanguageInfo', ('django_code','name','ind
 
 
 
-DJANGO_DEFAULT_LANGUAGE = 'en-us'
 gettext_noop = lambda s: s
 
 def to_locale(language):
@@ -81,11 +81,6 @@ def to_locale(language):
     else:
         return language.lower() 
         
-def assert_django_code(django_code):
-    if '_' in django_code:
-        raise Exception("Invalid language code %r. "
-            "Use values like 'en' or 'en-us'." % django_code)
-        
 
 class Site(Site):
     """
@@ -180,8 +175,6 @@ class Site(Site):
             modname = modname[:i]
         self.is_local_project_dir = not modname in self.user_apps
         
-        
-        
         def settings_subdirs(name):
             lst = []
             for p in self.get_settings_subdirs(name):
@@ -234,7 +227,9 @@ class Site(Site):
          'FIXTURE_DIRS': (),
          'INSTALLED_APPS': ('djangosite',),
          'LOCALE_PATHS': (),
-         'SERIALIZATION_MODULES': {'py': 'north.dpy'}}
+         'SECRET_KEY': '20227',
+         'SERIALIZATION_MODULES': {'py': 'north.dpy'},
+         '__file__': '...'}
      
         >>> pprint(Site(languages="en fr de").languages)
         (LanguageInfo(django_code='en', name='en', index=0, suffix=''),
@@ -500,7 +495,7 @@ class Site(Site):
         
         >>> from north import TestSite as Site
         >>> from north.dbutils import set_language
-        >>> from djangosite.utils import AttrDict
+        >>> from atelier.utils import AttrDict
         >>> def testit(site_languages):
         ...     site = Site(languages=site_languages)
         ...     obj = AttrDict(site.babelkw('name',de="Hallo",en="Hello",fr="Salut"))
@@ -610,7 +605,7 @@ class Site(Site):
         
         >>> from north import TestSite as Site
         >>> from north.dbutils import set_language
-        >>> from djangosite.utils import AttrDict
+        >>> from atelier.utils import AttrDict
         >>> def testit(site_languages):
         ...     site = Site(languages=site_languages)
         ...     obj = AttrDict(site.babelkw('name',de="Hallo",en="Hello",fr="Salut"))
@@ -674,8 +669,9 @@ class TestSite(Site):
     """
     def __init__(self,*args,**kwargs):
         kwargs.update(no_local=True)
-        super(TestSite,self).__init__(__file__,{},*args,**kwargs)
+        g = dict(__file__=__file__)
+        super(TestSite,self).__init__(g,*args,**kwargs)
         
     #~ def run_djangosite_local(self):
         #~ pass
-        
\ No newline at end of file
+        
