@@ -1,7 +1,13 @@
+"""
+:copyright: Copyright 2013 by Luc Saffre.
+:license: BSD, see LICENSE for more details.
+"""
+
 SETUP_INFO = dict(
-  version = '0.1.1',
-  install_requires = ['djangosite==0.1.1','Babel'],
+  version = '0.1.2',
+  install_requires = ['djangosite==0.1.2','Babel'],
   #~ name = 'django-north',
+  test_suite = 'tests',
   name = 'North',
   description = "Another way to migrate Django databases",
   #~ long_description=open('README.txt').read(),
@@ -21,8 +27,8 @@ Basic usage in your `settings.py` file is::
   SITE = Site(__file__,globals(),'myapp1','myapp2',...)
   # your settings here
       
-See the `Usage <http://site.lino-framework.org/usage.html>` page
-for `django-site` which applies entirely for a `North` site.
+See the `Usage <http://site.lino-framework.org/usage.html>`_ page
+for `djangosite` which applies entirely for a `North` site.
 
 North works by adding a new serialization format "py" 
 to Django's `SERIALIZATION_MODULES` setting.
@@ -33,13 +39,13 @@ Django's `dump` command::
 
 Instantiating a North Site will install sensible default values 
 for certain Django settings, including `INSTALLED_APPS` and 
-`SERIALIZATION_MODULES`.""",
+`SERIALIZATION_MODULES`.
+""",
   license = 'Free BSD',
   packages = ['north'],
   author = 'Luc Saffre',
   author_email = 'luc.saffre@gmail.com',
   url = "http://north.lino-framework.org",
-  #~ test_suite = 'lino.test_apps',
   classifiers="""\
   Programming Language :: Python
   Programming Language :: Python :: 2.6
